@@ -7,19 +7,13 @@
  * Increment the reference count for an #AccessibleEditableText object.
  *       Since AccessibleEditableText is derived from AccessibleText,
  *       this is the same as AccessibleText_ref().
- *
- * Returns: (no return code implemented yet).
- *
  **/
-int
+void
 AccessibleEditableText_ref (AccessibleEditableText *obj)
 {
-  Accessibility_EditableText_ref (*obj, spi_ev ());
-  return 0;
+  cspi_object_ref (obj);
 }
 
-
-
 /**
  * AccessibleEditableText_unref:
  * @obj: a pointer to the #AccessibleEditableText object on which to operate.
@@ -27,19 +21,13 @@ AccessibleEditableText_ref (AccessibleEditableText *obj)
  * Decrement the reference count for an #AccessibleEdiitableText object.
  *       Since AccessibleEditableText is derived from AccessibleText,
  *       this is the same as AccessibleText_unref().
- *
- * Returns: (no return code implemented yet).
- *
  **/
-int
+void
 AccessibleEditableText_unref (AccessibleEditableText *obj)
 {
-  Accessibility_EditableText_unref (*obj, spi_ev ());
-  return 0;
+  cspi_object_unref (obj);
 }
 
-
-
 /**
  * AccessibleEditableText_setAttributes:
  * @obj: a pointer to the #AccessibleEditableText object to modify.
@@ -52,23 +40,28 @@ AccessibleEditableText_unref (AccessibleEditableText *obj)
  *          object, and the bounds of the range.
  *
  * Returns: #TRUE if the operation was successful, otherwise #FALSE.
- *
  **/
-boolean
+SPIBoolean
 AccessibleEditableText_setAttributes (AccessibleEditableText *obj,
 				      const char *attributes,
 				      long int startPos,
 				      long int endPos)
 {
-  return (boolean)
-    Accessibility_EditableText_setAttributes (*obj,
+  SPIBoolean retval;
+
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = 
+    Accessibility_EditableText_setAttributes (CSPI_OBJREF (obj),
 					      (CORBA_char *) attributes,
 					      (CORBA_long) startPos,
-					      (CORBA_long) endPos, spi_ev ());
+					      (CORBA_long) endPos, cspi_ev ());
+
+  cspi_return_val_if_ev ("setAttributes", FALSE);
+
+  return retval;
 }
 
-
-
 /**
  * AccessibleEditableText_setTextContents:
  * @obj: a pointer to the #AccessibleEditableText object to modify.
@@ -78,19 +71,23 @@ AccessibleEditableText_setAttributes (AccessibleEditableText *obj,
  * Replace the entire text contents of an #AccessibleEditableText object.
  *
  * Returns: #TRUE if the operation was successful, otherwise #FALSE.
- *
  **/
-boolean
+SPIBoolean
 AccessibleEditableText_setTextContents (AccessibleEditableText *obj,
                                         const char *newContents)
 {
-  Accessibility_EditableText_setTextContents (*obj,
-					      (CORBA_char *) newContents, spi_ev ());
-  return TRUE; /* TODO: make bonobo method return a boolean */
+  SPIBoolean retval;
+
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_EditableText_setTextContents (CSPI_OBJREF (obj),
+				       (CORBA_char *) newContents, cspi_ev ());
+
+  cspi_return_val_if_ev ("setTextContents", FALSE);
+
+  return retval;
 }
 
-
-
 /**
  * AccessibleEditableText_insertText:
  * @obj: a pointer to the #AccessibleEditableText object to modify.
@@ -105,22 +102,26 @@ AccessibleEditableText_setTextContents (AccessibleEditableText *obj,
  *       variable-width encoding.
  *
  * Returns: #TRUE if the operation was successful, otherwise #FALSE.
- *
  **/
-boolean
+SPIBoolean
 AccessibleEditableText_insertText (AccessibleEditableText *obj,
                                    long int position,
-                                   char *text,
+                                   const char *text,
                                    long int length)
 {
-  Accessibility_EditableText_insertText (*obj,
-					 (CORBA_long) position, (CORBA_char *) text,
-					 (CORBA_long) length, spi_ev ());
-  return TRUE;
+  SPIBoolean retval;
+
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_EditableText_insertText (CSPI_OBJREF (obj),
+					 (CORBA_long) position, (const CORBA_char *) text,
+					 (CORBA_long) length, cspi_ev ());
+
+  cspi_return_val_if_ev ("insertText", FALSE);
+
+  return retval;
 }
 
-
-
 /**
  * AccessibleEditableText_copyText:
  * @obj: a pointer to the #AccessibleEditableText object to modify.
@@ -134,19 +135,23 @@ AccessibleEditableText_insertText (AccessibleEditableText *obj,
  * @see: AccessibleEditableText_pasteText 
  *
  * Returns: #TRUE if the operation was successful, otherwise #FALSE.
- *
  **/
-boolean
+SPIBoolean
 AccessibleEditableText_copyText (AccessibleText *obj,
                                  long int startPos,
                                  long int endPos)
 {
-  Accessibility_EditableText_copyText (*obj,
-				       (CORBA_long) startPos, (CORBA_long) endPos, spi_ev ());
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  Accessibility_EditableText_copyText (
+    CSPI_OBJREF (obj), (CORBA_long) startPos,
+    (CORBA_long) endPos, cspi_ev ());
+
+  cspi_return_val_if_ev ("copyText", FALSE);
+
   return TRUE;
 }
 
-
 /**
  * AccessibleEditableText_cutText:
  * @obj: a pointer to the #AccessibleEditableText object to modify.
@@ -161,20 +166,25 @@ AccessibleEditableText_copyText (AccessibleText *obj,
  * @see: AccessibleEditableText_pasteText
  *
  * Returns: #TRUE if operation was successful, #FALSE otherwise.
- *
  **/
-boolean
+SPIBoolean
 AccessibleEditableText_cutText (AccessibleEditableText *obj,
                                 long int startPos,
                                 long int endPos)
 {
-  Accessibility_EditableText_cutText (*obj,
-				       (CORBA_long) startPos, (CORBA_long) endPos, spi_ev ());
-  return TRUE;
+  SPIBoolean retval;
+
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_EditableText_cutText (
+    CSPI_OBJREF (obj),
+    (CORBA_long) startPos, (CORBA_long) endPos, cspi_ev ());
+
+  cspi_return_val_if_ev ("cutText", FALSE);
+
+  return retval;
 }
 
-
-
 /**
  * AccessibleEditableText_deleteText:
  * @obj: a pointer to the #AccessibleEditableText object to modify.
@@ -189,20 +199,25 @@ AccessibleEditableText_cutText (AccessibleEditableText *obj,
  * @see: AccessibleEditableText_cutText
  *
  * Returns: #TRUE if the operation was successful, otherwise #FALSE.
- *
  **/
-boolean
+SPIBoolean
 AccessibleEditableText_deleteText (AccessibleEditableText *obj,
                                    long startPos,
                                    long endPos)
 {
-  Accessibility_EditableText_deleteText (*obj,
-				       (CORBA_long) startPos, (CORBA_long) endPos, spi_ev ());
-  return TRUE;
+  SPIBoolean retval;
+
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_EditableText_deleteText (
+    CSPI_OBJREF (obj),
+    (CORBA_long) startPos, (CORBA_long) endPos, cspi_ev ());
+
+  cspi_return_val_if_ev ("deleteText", FALSE);
+
+  return retval;
 }
 
-
-
 /**
  * AccessibleEditableText_pasteText:
  * @obj: a pointer to the #AccessibleEditableText object to modify.
@@ -215,14 +230,19 @@ AccessibleEditableText_deleteText (AccessibleEditableText *obj,
  *       variable-width encoding.
  *
  * Returns: #TRUE if the operation was successful, otherwise #FALSE.
- *
  **/
-boolean
+SPIBoolean
 AccessibleEditableText_pasteText (AccessibleEditableText *obj,
                                   long int position)
 {
-  Accessibility_EditableText_pasteText (*obj,
-					(CORBA_long) position, spi_ev ());
-  return TRUE;
-}
+  SPIBoolean retval;
 
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_EditableText_pasteText (
+    CSPI_OBJREF (obj), (CORBA_long) position, cspi_ev ());
+
+  cspi_return_val_if_ev ("pasteText", FALSE);
+
+  return retval;
+}
