@@ -187,6 +187,17 @@ impl_accessibility_component_get_mdi_z_order (PortableServer_Servant servant,
   return (CORBA_short) atk_component_get_mdi_zorder (component);
 }
 
+static CORBA_boolean
+impl_accessibility_component_grab_focus (PortableServer_Servant servant,
+					 CORBA_Environment     *ev)
+{
+  AtkComponent *component = get_component_from_servant (servant);
+
+  g_return_val_if_fail (component != NULL, FALSE);
+
+  return atk_component_grab_focus (component);
+}
+
 static void
 spi_component_class_init (SpiComponentClass *klass)
 {
@@ -200,6 +211,7 @@ spi_component_class_init (SpiComponentClass *klass)
         epv->getSize = impl_accessibility_component_get_size;
 	epv->getLayer = impl_accessibility_component_get_layer;
 	epv->getMDIZOrder = impl_accessibility_component_get_mdi_z_order;
+	epv->grabFocus = impl_accessibility_component_grab_focus;
 }
 
 static void
