@@ -24,7 +24,7 @@
 
 #include <config.h>
 
-#undef SPI_DEBUG
+#define  SPI_DEBUG
 
 #include <string.h>
 #include <ctype.h>
@@ -500,7 +500,10 @@ spi_notify_keylisteners (GList                          **key_listeners,
     }
 
   g_slist_free (notify);
-  
+
+#ifdef SPI_DEBUG
+  if (is_consumed) g_message ("consumed\n");
+#endif
   return is_consumed;
 }
 
