@@ -171,7 +171,7 @@ int main (int argc, char** argv){
   }
       /* TODO: enable fractional magnifications option? */
   if (global_options.target_display) {
-    snprintf (env_string, (size_t) (ENV_STRING_MAX_SIZE-1), "DISPLAY=%s", global_options.target_display);
+    g_snprintf (env_string, (size_t) (ENV_STRING_MAX_SIZE-1), "DISPLAY=%s", global_options.target_display);
     putenv (env_string);
   }
   gtk_init (&argc, &argv);
@@ -531,7 +531,11 @@ impl_magnifier_clear_all_zoom_regions (PortableServer_Servant servant,
 static void
 impl_magnifier_exit (PortableServer_Servant servant, CORBA_Environment *ev)
 {
-	;
+	Magnifier *magnifier = MAGNIFIER (bonobo_object_from_servant (servant));
+	if (magnifier->mag_data->zoom_regions) 
+		g_list_free (magnifier->mag_data->zoom_regions);
+	g_free (magnifier->mag_data);
+	magnifier_exit();
 }
 
 static void
